Eigensystem is a list-based class for storing the results of applying Singular Value Decomposition (SVD) to a feature by assay data set. Objects are normally created by compute,Eigensystem-method.
Eigensystem objects contain the following slots
matrix:matrix containing the feature by assay data without missing valuessignMatrix:matrix containing the sign of each element in matrixassayMatrix:matrix containing additional information about assays, with rows as assays and columns as additional variablesfeatureMatrix:matrix containing additional information about features, with rows as features and columns as additional variableseigenassays:matrix containing the feature by eigenassay data, with each column in eigenassays corresponding to a left singular vector, representing genome-wide expression, proteome-wide abundance or metabolome-wide intensity in the corresponding eigenassayeigenexpressions:numeric vector containing the eigenexpression fraction of each eigenfeature, eigenassay-pair, constituting the diagonal elements of the diagonal matrix connecting the left and right singular values; the diagonal matrix reflects the decoupling and decorrelation of the data, with expression of each eigenfeature restricted to the corresponding eigenassayeigenfeatures:matrix containing the eigenfeatures by assay data, with each row corresponding to a right singular vector, representing the expression, abundance or intensity of the corresponding eigenfeature across all assaysassaycorrelations:matrix containing the correlation between the eigenassays as rows and the assays as columnsfeaturecorrelations:matrix containing the correlation between the eigenfeatures as rows and features as columnsfractions:numeric vector containing the eigenexpression fraction for each eigenfeature, eigenassay-pair, defined as the relative fraction of overall expression that each eigenfeature and eigenassay captureentropy:numeric value between 0 and 1 giving the Shannon entropy as measure for data complexity, with an entropy of 0 corresponding to an ordered and redundant data set with all expression captured by a single eigenfeature, eigenassay-pair, and an entropy of 1 corresponding to a disordered and random data set with all eigenfeature, eigenassay-pairs equally expressedapply:character containing whether the eigensystem should be computed for the actual data or the variance in the dataexcludeEigenfeatures:numeric vector containing eigenfeature 1 and 2 in case they capture >85% of the data with eigenfeature 2 capturing at least 15%, otherwise numeric value containing eigenfeature 1colorIdFeatures:numeric vector or factor containing annotation information on the featuresmatrix(x), matrix(x) <- valuesignMatrix(x), signMatrix(x) <- valueassayMatrix(x), assayMatrix(x) <- valuefeatureMatrix(x), featureMatrix(x) <- valueeigenassays(x), eigenassays(x) <- valueeigenexpressions(x), eigenexpressions(x) <- valueeigenfeatures(x), eigenfeatures(x) <- valueassaycorrelations(x), assaycorrelations(x) <- valuefeaturecorrelations(x), featurecorrelations(x) <- valuefractions(x), fractions(x) <- valueentropy(x), entropy(x) <- valueapply(x), apply(x) <- valueexcludeEigenfeatures(x), excludeEigenfeatures(x) <- valuecolorIdFeatures(x), colorIdFeatures(x) <- valueEigensystem class stores the original data and all SVD-derived information obtained with compute.
Data in the Eigensystem are organized into different slots,
matrix, signMatrix, assayMatrix, featureMatrix,
eigenassays, eigenexpressions, eigenfeatures,
assaycorrelations, featurecorrelations, fractions,
entropy, apply, excludeEigenfeatures, and colorIdFeatures.
Brief descriptions of these slots are provided below.
## Metabolomics starvation data obtained from http://genomics-pubs.princeton.edu/StarvationMetabolomics/Download.shtml
data(StarvationData)
## An object from class Eigensystem is obtained with the compute method
eigensystem <- compute(StarvationData)
## Obtain entropy
entropy(eigensystem)
Run the code above in your browser using DataLab